@@ -131,7 +131,7 @@ class App:
 
                 response = handler(request, **kwargs)
             else:
-                response = self.default_response()
+                return self.default_response()
 
         except Exception as e:
             error = traceback.format_exc()
@@ -140,7 +140,7 @@ class App:
         return response
 
     def default_response(self):
-        self.exception_handler.handle_404()
+        return self.exception_handler.handle_404()
 
     def find_handler(self, request_path):
         for path, handler in self.routes.items():
